@@ -1,13 +1,15 @@
-from langchain_core.messages import HumanMessage
+import json
 import os
 import sys
+from typing import Literal
+
 root_dir = os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 sys.path.append(root_dir)
 
 from agentic_search.chains.text import get_content_summary_chain
 
 
-def get_running_summary(items: list[str]):
+def get_running_summary(items: list[str], llm_provider: Literal["ollama", "openai"] = "ollama"):
     """
     Get a running summary from a list of items.
 
@@ -20,10 +22,10 @@ def get_running_summary(items: list[str]):
         if summary == "":
             summary = current_item
         else:
-            summary = get_content_summary_chain().invoke({
+            summary = get_content_summary_chain(llm_provider).invoke({
                 "content": summary + "\n\n" + current_item,
             })
     
     return {
-        "summary": summary
+        "summary": json.loads(summary)["content"]
     }
\ No newline at end of file
